@@ -7,6 +7,11 @@ import snoozingmail.gmail.send as send_email
 import snoozingmail.gmail.modify as modify_email
 
 class Snoozin:
+    """The interface into gmail api wrapper
+
+    Has methods to read, send, and label messages
+    in the connected gmail account.
+    """
     def __init__(self, credentials):
         """Initialize the Snoozin object by creating the gmail
         service using the provided credentials file.
@@ -20,8 +25,9 @@ class Snoozin:
         """Get message ids for messages that match the given query
         
         Args:
-            query: String used to filter messages returned.
-            Eg.- 'from:user@some_domain.com' for Messages from a particular sender.
+            query: String used to filter messages returned. (ex:
+                   'from:user@some_domain.com' for Messages from 
+                   a particular sender.)
 
         Returns:
             List of message ids
@@ -33,8 +39,8 @@ class Snoozin:
         """Get message ids for messages that have all the given labels
         
         Args:
-            label_ids: list of label ids that must be included
-            Eg.- '['STARRED', 'UNREAD']' for starred unread emails 
+            label_ids: list of label ids that must be included (ex: 
+                       '['STARRED', 'UNREAD']' for starred unread emails)
 
         Returns:
             List of message ids
